# hitfactorpy

[![Main](https://github.com/cahna/hitfactorpy/actions/workflows/main.yaml/badge.svg)](https://github.com/cahna/hitfactorpy/actions/workflows/main.yaml)

Python tools for parsing and analyzing practical match reports.

## Status

**Work in progress...**

Documentation website: [https:/cahna.github.io/hitfactorpy](https:/cahna.github.io/hitfactorpy)

Currently only supports USPSA match reports.

## Library usage

See parsers available in [`hitfactorpy.parsers.match_report`](https://github.com/cahna/hitfactorpy/tree/main/hitfactorpy/parsers/match_report) and examples in [repository's `tests` directory](https://github.com/cahna/hitfactorpy/tree/main/tests).

## CLI Usage

After installing, run the `hitfactorpy` command should be added to `$PATH`.

```console
$ hitfactorpy --help
```

[Complete CLI documentation](https://cahna.github.io/hitfactorpy/)
